@@ -21,10 +21,10 @@ using OpenQA.Selenium.BiDi.Communication;
 
 namespace OpenQA.Selenium.BiDi.BrowsingContext;
 
-internal sealed class HandleUserPromptCommand(HandleUserPromptCommandParameters @params)
-    : Command<HandleUserPromptCommandParameters, EmptyResult>(@params, "browsingContext.handleUserPrompt");
+internal sealed class HandleUserPromptCommand(HandleUserPromptParameters @params)
+    : Command<HandleUserPromptParameters, EmptyResult>(@params, "browsingContext.handleUserPrompt");
 
-internal sealed record HandleUserPromptCommandParameters(BrowsingContext Context, bool? Accept, string? UserText) : CommandParameters;
+internal sealed record HandleUserPromptParameters(BrowsingContext Context, bool? Accept, string? UserText) : Parameters;
 
 public sealed class HandleUserPromptOptions : CommandOptions
 {
