@@ -75,6 +75,7 @@ public sealed class Broker : IAsyncDisposable
                 new BrowserUserContextConverter(bidi),
                 new BrowserClientWindowConverter(),
                 new NavigationConverter(),
+                new CollectorConverter(_bidi),
                 new InterceptConverter(_bidi),
                 new RequestConverter(),
                 new ChannelConverter(),
@@ -86,6 +87,7 @@ public sealed class Broker : IAsyncDisposable
                 new DateTimeOffsetConverter(),
                 new PrintPageRangeConverter(),
                 new InputOriginConverter(),
+                new WebExtensionConverter(_bidi),
                 new SubscriptionConverter(),
                 new JsonStringEnumConverter(JsonNamingPolicy.CamelCase),
 
@@ -121,22 +123,34 @@ public sealed class Broker : IAsyncDisposable
 
     private async Task ReceiveMessagesAsync(CancellationToken cancellationToken)
     {
-        while (!cancellationToken.IsCancellationRequested)
+        try
         {
-            try
+            while (!cancellationToken.IsCancellationRequested)
             {
                 var data = await _transport.ReceiveAsync(cancellationToken).ConfigureAwait(false);
 
-                ProcessReceivedMessage(data);
-            }
-            catch (Exception ex)
-            {
-                if (cancellationToken.IsCancellationRequested is not true && _logger.IsEnabled(LogEventLevel.Error))
+                try
                 {
-                    _logger.Error($"Couldn't process received BiDi remote message: {ex}");
+                    ProcessReceivedMessage(data);
+                }
+                catch (Exception ex)
+                {
+                    if (_logger.IsEnabled(LogEventLevel.Error))
+                    {
+                        _logger.Error($"Unhandled error occured while processing remote message: {ex}");
+                    }
                 }
             }
         }
+        catch (Exception ex) when (ex is not OperationCanceledException)
+        {
+            if (_logger.IsEnabled(LogEventLevel.Error))
+            {
+                _logger.Error($"Unhandled error occured while receiving remote messages: {ex}");
+            }
+
+            throw;
+        }
     }
 
     private async Task ProcessEventsAwaiterAsync()
@@ -274,27 +288,7 @@ public sealed class Broker : IAsyncDisposable
 
         eventHandlers.Remove(eventHandler);
 
-        if (subscription is not null)
-        {
-            await _bidi.SessionModule.UnsubscribeAsync([subscription]).ConfigureAwait(false);
-        }
-        else
-        {
-            if (eventHandler.Contexts is not null)
-            {
-                if (!eventHandlers.Any(h => eventHandler.Contexts.Equals(h.Contexts)) && !eventHandlers.Any(h => h.Contexts is null))
-                {
-                    await _bidi.SessionModule.UnsubscribeAsync([eventHandler.EventName], new() { Contexts = eventHandler.Contexts }).ConfigureAwait(false);
-                }
-            }
-            else
-            {
-                if (!eventHandlers.Any(h => h.Contexts is not null) && !eventHandlers.Any(h => h.Contexts is null))
-                {
-                    await _bidi.SessionModule.UnsubscribeAsync([eventHandler.EventName]).ConfigureAwait(false);
-                }
-            }
-        }
+        await _bidi.SessionModule.UnsubscribeAsync([subscription]).ConfigureAwait(false);
     }
 
     public async ValueTask DisposeAsync()
