@@ -21,9 +21,9 @@ using OpenQA.Selenium.BiDi.Communication;
 
 namespace OpenQA.Selenium.BiDi.Script;
 
-internal sealed class RemovePreloadScriptCommand(RemovePreloadScriptCommandParameters @params)
-    : Command<RemovePreloadScriptCommandParameters, EmptyResult>(@params, "script.removePreloadScript");
+internal sealed class RemovePreloadScriptCommand(RemovePreloadScriptParameters @params)
+    : Command<RemovePreloadScriptParameters, EmptyResult>(@params, "script.removePreloadScript");
 
-internal sealed record RemovePreloadScriptCommandParameters(PreloadScript Script) : CommandParameters;
+internal sealed record RemovePreloadScriptParameters(PreloadScript Script) : Parameters;
 
 public sealed class RemovePreloadScriptOptions : CommandOptions;
