@@ -22,6 +22,6 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.Session;
 
 internal sealed class EndCommand()
-    : Command<CommandParameters, EmptyResult>(CommandParameters.Empty, "session.end");
+    : Command<Parameters, EmptyResult>(Parameters.Empty, "session.end");
 
 public sealed class EndOptions : CommandOptions;
