@@ -32,28 +32,21 @@ internal sealed class SessionModule(Broker broker) : Module(broker)
 
     public async Task<SubscribeResult> SubscribeAsync(IEnumerable<string> events, SubscribeOptions? options = null)
     {
-        var @params = new SubscribeCommandParameters(events, options?.Contexts);
+        var @params = new SubscribeParameters(events, options?.Contexts);
 
         return await Broker.ExecuteCommandAsync<SubscribeCommand, SubscribeResult>(new(@params), options).ConfigureAwait(false);
     }
 
     public async Task<EmptyResult> UnsubscribeAsync(IEnumerable<Subscription> subscriptions, UnsubscribeByIdOptions? options = null)
     {
-        var @params = new UnsubscribeByIdCommandParameters(subscriptions);
+        var @params = new UnsubscribeByIdParameters(subscriptions);
 
         return await Broker.ExecuteCommandAsync<UnsubscribeByIdCommand, EmptyResult>(new UnsubscribeByIdCommand(@params), options).ConfigureAwait(false);
     }
 
-    public async Task<EmptyResult> UnsubscribeAsync(IEnumerable<string> eventNames, UnsubscribeByAttributesOptions? options = null)
-    {
-        var @params = new UnsubscribeByAttributesCommandParameters(eventNames, options?.Contexts);
-
-        return await Broker.ExecuteCommandAsync<UnsubscribeByAttributesCommand, EmptyResult>(new UnsubscribeByAttributesCommand(@params), options).ConfigureAwait(false);
-    }
-
     public async Task<NewResult> NewAsync(CapabilitiesRequest capabilitiesRequest, NewOptions? options = null)
     {
-        var @params = new NewCommandParameters(capabilitiesRequest);
+        var @params = new NewParameters(capabilitiesRequest);
 
         return await Broker.ExecuteCommandAsync<NewCommand, NewResult>(new NewCommand(@params), options).ConfigureAwait(false);
     }
