@@ -18,28 +18,13 @@
 // </copyright>
 
 using OpenQA.Selenium.BiDi.Communication;
-using System;
 using System.Collections.Generic;
 
 namespace OpenQA.Selenium.BiDi.Session;
 
-internal sealed class UnsubscribeByIdCommand(UnsubscribeByIdCommandParameters @params)
-    : Command<UnsubscribeByIdCommandParameters, EmptyResult>(@params, "session.unsubscribe");
+internal sealed class UnsubscribeByIdCommand(UnsubscribeByIdParameters @params)
+    : Command<UnsubscribeByIdParameters, EmptyResult>(@params, "session.unsubscribe");
 
-internal sealed class UnsubscribeByAttributesCommand(UnsubscribeByAttributesCommandParameters @params)
-    : Command<UnsubscribeByAttributesCommandParameters, EmptyResult>(@params, "session.unsubscribe");
-
-internal sealed record UnsubscribeByIdCommandParameters(IEnumerable<Subscription> Subscriptions) : CommandParameters;
+internal sealed record UnsubscribeByIdParameters(IEnumerable<Subscription> Subscriptions) : Parameters;
 
 public sealed class UnsubscribeByIdOptions : CommandOptions;
-
-internal sealed record UnsubscribeByAttributesCommandParameters(
-    IEnumerable<string> Events,
-    [property: Obsolete("Contexts param is deprecated and will be removed in the future versions")]
-    // https://w3c.github.io/webdriver-bidi/#type-session-UnsubscribeByAttributesRequest
-    IEnumerable<BrowsingContext.BrowsingContext>? Contexts) : CommandParameters;
-
-public sealed class UnsubscribeByAttributesOptions : CommandOptions
-{
-    public IEnumerable<BrowsingContext.BrowsingContext>? Contexts { get; set; }
-}
