@@ -62,13 +62,6 @@ public class DevToolsSession : IDevToolsSession
 
     private readonly static ILogger logger = Internal.Logging.Log.GetLogger<DevToolsSession>();
 
-    /// <summary>
-    /// Initializes a new instance of the DevToolsSession class, using the specified WebSocket endpoint.
-    /// </summary>
-    /// <param name="endpointAddress"></param>
-    [Obsolete("Use DevToolsSession(string endpointAddress, DevToolsOptions options)")]
-    public DevToolsSession(string endpointAddress) : this(endpointAddress, new DevToolsOptions()) { }
-
     /// <summary>
     /// Initializes a new instance of the DevToolsSession class, using the specified WebSocket endpoint and specified DevTools options.
     /// </summary>
@@ -473,7 +466,7 @@ public class DevToolsSession : IDevToolsSession
         await this.Domains.Target.SetAutoAttach().ConfigureAwait(false);
         LogTrace("AutoAttach is set.", this.attachedTargetId);
 
-        // The Target domain needs to send Session-less commands! Else the waitForDebugger setting in setAutoAttach wont work!
+        // The Target domain needs to send Session-less commands! Else the waitForDebugger setting in setAutoAttach won't work!
         if (options.WaitForDebuggerOnStart)
         {
             var setAutoAttachCommand = Domains.Target.CreateSetAutoAttachCommand(true);
