@@ -18,7 +18,6 @@
 // </copyright>
 
 using NUnit.Framework;
-using OpenQA.Selenium.BiDi.Modules.Script;
 using System.Threading.Tasks;
 
 namespace OpenQA.Selenium.BiDi.Script;
@@ -113,7 +112,7 @@ class EvaluateParametersTest : BiDiTestFixture
     [Test]
     public async Task CanEvaluateInARealm()
     {
-        await bidi.BrowsingContext.CreateAsync(Modules.BrowsingContext.ContextType.Tab);
+        await bidi.BrowsingContext.CreateAsync(BrowsingContext.ContextType.Tab);
 
         var realms = await bidi.Script.GetRealmsAsync();
 
