@@ -19,10 +19,9 @@
 
 using NUnit.Framework;
 
-namespace OpenQA.Selenium.Edge
+namespace OpenQA.Selenium.Edge;
+
+[TestFixture]
+public class EdgeSpecificTests : DriverTestFixture
 {
-    [TestFixture]
-    public class EdgeSpecificTests : DriverTestFixture
-    {
-    }
 }
