@@ -17,6 +17,8 @@
 
 package org.openqa.selenium.grid.node.config;
 
+import static org.openqa.selenium.remote.CapabilityType.ENABLE_DOWNLOADS;
+
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.HashMultimap;
 import com.google.common.collect.ImmutableMap;
@@ -75,6 +77,7 @@ public class NodeOptions {
   public static final int DEFAULT_SESSION_TIMEOUT = 300;
   public static final int DEFAULT_DRAIN_AFTER_SESSION_COUNT = 0;
   public static final int DEFAULT_CONNECTION_LIMIT = 10;
+  public static final boolean DEFAULT_DELETE_SESSION_ON_UI = false;
   public static final boolean DEFAULT_ENABLE_CDP = true;
   public static final boolean DEFAULT_ENABLE_BIDI = true;
   static final String NODE_SECTION = "node";
@@ -301,6 +304,13 @@ public class NodeOptions {
         DEFAULT_DRAIN_AFTER_SESSION_COUNT);
   }
 
+  @VisibleForTesting
+  boolean isSessionDeletedOnUi() {
+    return config
+        .getBool(NODE_SECTION, "delete-session-on-ui")
+        .orElse(DEFAULT_DELETE_SESSION_ON_UI);
+  }
+
   @VisibleForTesting
   boolean isVncEnabled() {
     List<String> vncEnvVars = DEFAULT_VNC_ENV_VARS;
@@ -748,9 +758,12 @@ public class NodeOptions {
               .setCapability("se:vncEnabled", true)
               .setCapability("se:noVncPort", noVncPort());
     }
-    if (isManagedDownloadsEnabled() && canConfigureDownloadsDir(capabilities)) {
+    if (isSessionDeletedOnUi()) {
       capabilities =
-          new PersistentCapabilities(capabilities).setCapability("se:downloadsEnabled", true);
+          new PersistentCapabilities(capabilities).setCapability("se:deleteSessionOnUi", true);
+    }
+    if (isManagedDownloadsEnabled() && canConfigureDownloadsDir(capabilities)) {
+      capabilities = new PersistentCapabilities(capabilities).setCapability(ENABLE_DOWNLOADS, true);
     }
     return capabilities;
   }
