@@ -17,19 +17,22 @@
 
 package org.openqa.selenium.remote;
 
+import org.jspecify.annotations.NullMarked;
+import org.jspecify.annotations.Nullable;
 import org.openqa.selenium.WebDriverException;
 import org.openqa.selenium.remote.service.DriverFinder;
 
 /** Thrown by {@link DriverFinder#getDriverPath()} (DriverService, Capabilities)}. */
+@NullMarked
 public class NoSuchDriverException extends WebDriverException {
 
   private static final String SUPPORT_URL = BASE_SUPPORT_URL + "/driver_location/";
 
-  public NoSuchDriverException(String reason) {
+  public NoSuchDriverException(@Nullable String reason) {
     super(reason);
   }
 
-  public NoSuchDriverException(String reason, Throwable cause) {
+  public NoSuchDriverException(@Nullable String reason, @Nullable Throwable cause) {
     super(reason, cause);
   }
 
