@@ -777,6 +777,140 @@ class LocalDistributorTest {
     }
   }
 
+  @Test
+  void shouldNotRejectRequestsWhenNodesHaveCapabilityButNoFreeSlots() throws URISyntaxException {
+    // Create a distributor with rejectUnsupportedCaps enabled
+    NewSessionQueue queue =
+        new LocalNewSessionQueue(
+            tracer,
+            new DefaultSlotMatcher(),
+            Duration.ofSeconds(2),
+            Duration.ofSeconds(2),
+            Duration.ofSeconds(1),
+            registrationSecret,
+            5);
+    LocalDistributor distributor =
+        new LocalDistributor(
+            tracer,
+            bus,
+            new PassthroughHttpClient.Factory(localNode),
+            new LocalSessionMap(tracer, bus),
+            queue,
+            new DefaultSlotSelector(),
+            registrationSecret,
+            Duration.ofMinutes(5),
+            true, // Enable rejectUnsupportedCaps
+            Duration.ofSeconds(5),
+            newSessionThreadPoolSize,
+            new DefaultSlotMatcher(),
+            Duration.ofSeconds(30));
+
+    // Create a node that supports Chrome with single slot
+    URI nodeUri = new URI("http://example:1234");
+    Node node =
+        LocalNode.builder(tracer, bus, nodeUri, nodeUri, registrationSecret)
+            .add(
+                new ImmutableCapabilities("browserName", "chrome"),
+                new TestSessionFactory(
+                    (id, c) ->
+                        new Session(id, nodeUri, new ImmutableCapabilities(), c, Instant.now())))
+            .maximumConcurrentSessions(1)
+            .build();
+    distributor.add(node);
+
+    // Occupy the node's only slot
+    SessionRequest sessionRequest =
+        new SessionRequest(
+            new RequestId(UUID.randomUUID()),
+            Instant.now(),
+            Set.of(W3C),
+            Set.of(new ImmutableCapabilities("browserName", "chrome")),
+            Map.of(),
+            Map.of());
+    Either<SessionNotCreatedException, CreateSessionResponse> result =
+        distributor.newSession(sessionRequest);
+    assertThat(result.isRight()).isTrue(); // Session created successfully
+
+    // Verify node has no available capacity but still supports Chrome
+    assertThat(distributor.getAvailableNodes()).isEmpty(); // No available nodes
+
+    // Test that the distributor status shows the node is still UP and supports Chrome
+    // even though it has no available capacity
+    DistributorStatus status = distributor.getStatus();
+    Set<NodeStatus> allNodes = status.getNodes();
+    assertThat(allNodes).hasSize(1);
+
+    NodeStatus nodeStatus = allNodes.iterator().next();
+    assertThat(nodeStatus.getAvailability()).isEqualTo(UP);
+
+    // Verify the node still supports Chrome capability even with no free slots
+    boolean supportsChrome =
+        nodeStatus.hasCapability(
+            new ImmutableCapabilities("browserName", "chrome"), new DefaultSlotMatcher());
+    assertThat(supportsChrome).isTrue();
+
+    // Verify the node has no capacity (all slots occupied)
+    assertThat(nodeStatus.hasCapacity()).isFalse();
+  }
+
+  @Test
+  void shouldRejectRequestsWhenNoNodesHaveCapability() throws URISyntaxException {
+    // Create a distributor with rejectUnsupportedCaps enabled
+    NewSessionQueue queue =
+        new LocalNewSessionQueue(
+            tracer,
+            new DefaultSlotMatcher(),
+            Duration.ofSeconds(2),
+            Duration.ofSeconds(2),
+            Duration.ofSeconds(1),
+            registrationSecret,
+            5);
+    LocalDistributor distributor =
+        new LocalDistributor(
+            tracer,
+            bus,
+            new PassthroughHttpClient.Factory(localNode),
+            new LocalSessionMap(tracer, bus),
+            queue,
+            new DefaultSlotSelector(),
+            registrationSecret,
+            Duration.ofMinutes(5),
+            true, // Enable rejectUnsupportedCaps
+            Duration.ofSeconds(5),
+            newSessionThreadPoolSize,
+            new DefaultSlotMatcher(),
+            Duration.ofSeconds(30));
+
+    // Create a node that only supports Chrome
+    URI nodeUri = new URI("http://example:1234");
+    Node node =
+        LocalNode.builder(tracer, bus, nodeUri, nodeUri, registrationSecret)
+            .add(
+                new ImmutableCapabilities("browserName", "chrome"),
+                new TestSessionFactory(
+                    (id, c) ->
+                        new Session(id, nodeUri, new ImmutableCapabilities(), c, Instant.now())))
+            .build();
+    distributor.add(node);
+
+    // Add a Firefox request to the queue (unsupported capability)
+    SessionRequest unsupportedRequest =
+        new SessionRequest(
+            new RequestId(UUID.randomUUID()),
+            Instant.now(),
+            Set.of(W3C),
+            Set.of(new ImmutableCapabilities("browserName", "firefox")),
+            Map.of(),
+            Map.of());
+    queue.addToQueue(unsupportedRequest);
+
+    // Wait for checkMatchingSlot to run and reject the request
+    wait.until(obj -> queue.getQueueContents().isEmpty());
+
+    // The request should be rejected and removed from queue
+    assertThat(queue.getQueueContents()).isEmpty();
+  }
+
   @Test
   void shouldHandleAllNodesFullyOccupied() throws URISyntaxException {
     // Create a distributor
