@@ -18,13 +18,12 @@
 from typing import Optional
 
 from selenium.webdriver.common.driver_finder import DriverFinder
+from selenium.webdriver.ie.options import Options
+from selenium.webdriver.ie.service import Service
 from selenium.webdriver.remote.client_config import ClientConfig
 from selenium.webdriver.remote.remote_connection import RemoteConnection
 from selenium.webdriver.remote.webdriver import WebDriver as RemoteWebDriver
 
-from .options import Options
-from .service import Service
-
 
 class WebDriver(RemoteWebDriver):
     """Controls the IEServerDriver and allows you to drive Internet
