@@ -16,21 +16,21 @@
 # under the License.
 
 import logging
-import platform
 import string
+import sys
 import warnings
 from base64 import b64encode
 from typing import Optional
 from urllib import parse
+from urllib.parse import unquote, urlparse
 
 import urllib3
 
 from selenium import __version__
-
-from . import utils
-from .client_config import ClientConfig
-from .command import Command
-from .errorhandler import ErrorCode
+from selenium.webdriver.remote import utils
+from selenium.webdriver.remote.client_config import ClientConfig
+from selenium.webdriver.remote.command import Command
+from selenium.webdriver.remote.errorhandler import ErrorCode
 
 LOGGER = logging.getLogger(__name__)
 
@@ -125,6 +125,15 @@ remote_commands = {
     Command.GET_DOWNLOADABLE_FILES: ("GET", "/session/$sessionId/se/files"),
     Command.DOWNLOAD_FILE: ("POST", "/session/$sessionId/se/files"),
     Command.DELETE_DOWNLOADABLE_FILES: ("DELETE", "/session/$sessionId/se/files"),
+    # Federated Credential Management (FedCM)
+    Command.GET_FEDCM_TITLE: ("GET", "/session/$sessionId/fedcm/gettitle"),
+    Command.GET_FEDCM_DIALOG_TYPE: ("GET", "/session/$sessionId/fedcm/getdialogtype"),
+    Command.GET_FEDCM_ACCOUNT_LIST: ("GET", "/session/$sessionId/fedcm/accountlist"),
+    Command.CLICK_FEDCM_DIALOG_BUTTON: ("POST", "/session/$sessionId/fedcm/clickdialogbutton"),
+    Command.CANCEL_FEDCM_DIALOG: ("POST", "/session/$sessionId/fedcm/canceldialog"),
+    Command.SELECT_FEDCM_ACCOUNT: ("POST", "/session/$sessionId/fedcm/selectaccount"),
+    Command.SET_FEDCM_DELAY: ("POST", "/session/$sessionId/fedcm/setdelayenabled"),
+    Command.RESET_FEDCM_COOLDOWN: ("POST", "/session/$sessionId/fedcm/resetcooldown"),
 }
 
 
@@ -135,10 +144,18 @@ class RemoteConnection:
     https://github.com/SeleniumHQ/selenium/wiki/JsonWireProtocol
     """
 
-    browser_name = None
-    _client_config: ClientConfig = None
+    browser_name: Optional[str] = None
+    # Keep backward compatibility for AppiumConnection - https://github.com/SeleniumHQ/selenium/issues/14694
+    import os
+    import socket
 
-    system = platform.system().lower()
+    import certifi
+
+    _timeout = socket.getdefaulttimeout()
+    _ca_certs = os.getenv("REQUESTS_CA_BUNDLE") if "REQUESTS_CA_BUNDLE" in os.environ else certifi.where()
+    _client_config: Optional[ClientConfig] = None
+
+    system = sys.platform
     if system == "darwin":
         system = "mac"
 
@@ -146,6 +163,10 @@ class RemoteConnection:
     extra_headers = None
     user_agent = f"selenium/{__version__} (python {system})"
 
+    @property
+    def client_config(self):
+        return self._client_config
+
     @classmethod
     def get_timeout(cls):
         """:Returns:
@@ -154,7 +175,7 @@ class RemoteConnection:
         Remote Connection
         """
         warnings.warn(
-            "get_timeout() in RemoteConnection is deprecated, get timeout from ClientConfig instance instead",
+            "get_timeout() in RemoteConnection is deprecated, get timeout from client_config instead",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -168,7 +189,7 @@ class RemoteConnection:
             - timeout - timeout value for http requests in seconds
         """
         warnings.warn(
-            "set_timeout() in RemoteConnection is deprecated, set timeout to ClientConfig instance in constructor instead",
+            "set_timeout() in RemoteConnection is deprecated, set timeout in client_config instead",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -178,7 +199,7 @@ class RemoteConnection:
     def reset_timeout(cls):
         """Reset the http request timeout to socket._GLOBAL_DEFAULT_TIMEOUT."""
         warnings.warn(
-            "reset_timeout() in RemoteConnection is deprecated, use reset_timeout() in ClientConfig instance instead",
+            "reset_timeout() in RemoteConnection is deprecated, use reset_timeout() in client_config instead",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -193,7 +214,7 @@ class RemoteConnection:
         REQUESTS_CA_BUNDLE env variable if set.
         """
         warnings.warn(
-            "get_certificate_bundle_path() in RemoteConnection is deprecated, get ca_certs from ClientConfig instance instead",
+            "get_certificate_bundle_path() in RemoteConnection is deprecated, get ca_certs from client_config instead",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -209,7 +230,7 @@ class RemoteConnection:
             - path - path of a .pem encoded certificate chain.
         """
         warnings.warn(
-            "set_certificate_bundle_path() in RemoteConnection is deprecated, set ca_certs to ClientConfig instance in constructor instead",
+            "set_certificate_bundle_path() in RemoteConnection is deprecated, set ca_certs in client_config instead",
             DeprecationWarning,
             stacklevel=2,
         )
@@ -231,6 +252,9 @@ class RemoteConnection:
         }
 
         if parsed_url.username:
+            warnings.warn(
+                "Embedding username and password in URL could be insecure, use ClientConfig instead", stacklevel=2
+            )
             base64string = b64encode(f"{parsed_url.username}:{parsed_url.password}".encode())
             headers.update({"Authorization": f"Basic {base64string.decode()}"})
 
@@ -243,16 +267,14 @@ class RemoteConnection:
         return headers
 
     def _identify_http_proxy_auth(self):
-        url = self._proxy_url
-        url = url[url.find(":") + 3 :]
-        return "@" in url and len(url[: url.find("@")]) > 0
+        parsed_url = urlparse(self._proxy_url)
+        if parsed_url.username and parsed_url.password:
+            return True
 
     def _separate_http_proxy_auth(self):
-        url = self._proxy_url
-        protocol = url[: url.find(":") + 3]
-        no_protocol = url[len(protocol) :]
-        auth = no_protocol[: no_protocol.find("@")]
-        proxy_without_auth = protocol + no_protocol[len(auth) + 1 :]
+        parsed_url = urlparse(self._proxy_url)
+        proxy_without_auth = f"{parsed_url.scheme}://{parsed_url.hostname}:{parsed_url.port}"
+        auth = f"{parsed_url.username}:{parsed_url.password}"
         return proxy_without_auth, auth
 
     def _get_connection_manager(self):
@@ -275,7 +297,9 @@ class RemoteConnection:
                 return SOCKSProxyManager(self._proxy_url, **pool_manager_init_args)
             if self._identify_http_proxy_auth():
                 self._proxy_url, self._basic_proxy_auth = self._separate_http_proxy_auth()
-                pool_manager_init_args["proxy_headers"] = urllib3.make_headers(proxy_basic_auth=self._basic_proxy_auth)
+                pool_manager_init_args["proxy_headers"] = urllib3.make_headers(
+                    proxy_basic_auth=unquote(self._basic_proxy_auth)
+                )
             return urllib3.ProxyManager(self._proxy_url, **pool_manager_init_args)
 
         return urllib3.PoolManager(**pool_manager_init_args)
@@ -296,39 +320,44 @@ class RemoteConnection:
             init_args_for_pool_manager=init_args_for_pool_manager,
         )
 
+        # Keep backward compatibility for AppiumConnection - https://github.com/SeleniumHQ/selenium/issues/14694
+        RemoteConnection._timeout = self._client_config.timeout
+        RemoteConnection._ca_certs = self._client_config.ca_certs
         RemoteConnection._client_config = self._client_config
+        RemoteConnection.extra_headers = self._client_config.extra_headers or RemoteConnection.extra_headers
+        RemoteConnection.user_agent = self._client_config.user_agent or RemoteConnection.user_agent
 
         if remote_server_addr:
             warnings.warn(
-                "setting remote_server_addr in RemoteConnection() is deprecated, set in ClientConfig instance instead",
+                "setting remote_server_addr in RemoteConnection() is deprecated, set in client_config instead",
                 DeprecationWarning,
                 stacklevel=2,
             )
 
         if not keep_alive:
             warnings.warn(
-                "setting keep_alive in RemoteConnection() is deprecated, set in ClientConfig instance instead",
+                "setting keep_alive in RemoteConnection() is deprecated, set in client_config instead",
                 DeprecationWarning,
                 stacklevel=2,
             )
 
         if ignore_certificates:
             warnings.warn(
-                "setting ignore_certificates in RemoteConnection() is deprecated, set in ClientConfig instance instead",
+                "setting ignore_certificates in RemoteConnection() is deprecated, set in client_config instead",
                 DeprecationWarning,
                 stacklevel=2,
             )
 
         if init_args_for_pool_manager:
             warnings.warn(
-                "setting init_args_for_pool_manager in RemoteConnection() is deprecated, set in ClientConfig instance instead",
+                "setting init_args_for_pool_manager in RemoteConnection() is deprecated, set in client_config instead",
                 DeprecationWarning,
                 stacklevel=2,
             )
 
         if ignore_proxy:
             warnings.warn(
-                "setting ignore_proxy in RemoteConnection() is deprecated, set in ClientConfig instance instead",
+                "setting ignore_proxy in RemoteConnection() is deprecated, set in client_config instead",
                 DeprecationWarning,
                 stacklevel=2,
             )
@@ -375,7 +404,7 @@ class RemoteConnection:
         LOGGER.debug("%s %s %s", command_info[0], url, str(trimmed))
         return self._request(command_info[0], url, body=data)
 
-    def _request(self, method, url, body=None, timeout=120):
+    def _request(self, method, url, body=None):
         """Send an HTTP request to the remote server.
 
         :Args:
@@ -397,22 +426,22 @@ class RemoteConnection:
             body = None
 
         if self._client_config.keep_alive:
-            response = self._conn.request(method, url, body=body, headers=headers, timeout=timeout)
+            response = self._conn.request(method, url, body=body, headers=headers, timeout=self._client_config.timeout)
             statuscode = response.status
         else:
             conn = self._get_connection_manager()
             with conn as http:
-                response = http.request(method, url, body=body, headers=headers, timeout=timeout)
+                response = http.request(method, url, body=body, headers=headers, timeout=self._client_config.timeout)
             statuscode = response.status
         data = response.data.decode("UTF-8")
         LOGGER.debug("Remote response: status=%s | data=%s | headers=%s", response.status, data, response.headers)
         try:
             if 300 <= statuscode < 304:
                 return self._request("GET", response.headers.get("location", None))
-            if 399 < statuscode <= 500:
-                if statuscode == 401:
-                    return {"status": statuscode, "value": "Authorization Required"}
-                return {"status": statuscode, "value": str(statuscode) if not data else data.strip()}
+            if statuscode == 401:
+                return {"status": statuscode, "value": "Authorization Required"}
+            if statuscode >= 400:
+                return {"status": statuscode, "value": response.reason if not data else data.strip()}
             content_type = []
             if response.headers.get("Content-Type", None):
                 content_type = response.headers.get("Content-Type", None).split(";")
