@@ -15,11 +15,9 @@
 # specific language governing permissions and limitations
 # under the License.
 
-
 import pytest
 
 from selenium.common.exceptions import NoSuchElementException
-from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.wait import WebDriverWait
@@ -239,7 +237,9 @@ def test_is_element_displayed(driver, pages):
     assert not not_visible
 
 
-@pytest.mark.xfail_chrome
+@pytest.mark.xfail_edge
+@pytest.mark.xfail_firefox(reason="https://github.com/mozilla/geckodriver/issues/2224")
+@pytest.mark.xfail_remote(reason="https://github.com/mozilla/geckodriver/issues/2224")
 @pytest.mark.xfail_safari
 def test_move_window_position(driver, pages):
     pages.load("blank.html")
@@ -273,17 +273,23 @@ def test_change_window_size(driver, pages):
     assert size["height"] == newSize[1]
 
 
-@pytest.mark.xfail_firefox(raises=WebDriverException)
-@pytest.mark.xfail_remote
-@pytest.mark.xfail_safari
+@pytest.mark.xfail_ie(raises=AttributeError, reason="Logging API is no longer available")
+@pytest.mark.xfail_firefox(raises=AttributeError, reason="Logging API is no longer available")
+@pytest.mark.xfail_remote(raises=AttributeError, reason="Logging API is no longer available")
+@pytest.mark.xfail_safari(raises=AttributeError, reason="Logging API is no longer available")
+@pytest.mark.xfail_webkitgtk(raises=AttributeError, reason="Logging API is no longer available")
+@pytest.mark.xfail_wpewebkit(raises=AttributeError, reason="Logging API is no longer available")
 def test_get_log_types(driver, pages):
     pages.load("blank.html")
     assert isinstance(driver.log_types, list)
 
 
-@pytest.mark.xfail_firefox(raises=WebDriverException)
-@pytest.mark.xfail_remote
-@pytest.mark.xfail_safari
+@pytest.mark.xfail_ie(raises=AttributeError, reason="Logging API is no longer available")
+@pytest.mark.xfail_firefox(raises=AttributeError, reason="Logging API is no longer available")
+@pytest.mark.xfail_remote(raises=AttributeError, reason="Logging API is no longer available")
+@pytest.mark.xfail_safari(raises=AttributeError, reason="Logging API is no longer available")
+@pytest.mark.xfail_webkitgtk(raises=AttributeError, reason="Logging API is no longer available")
+@pytest.mark.xfail_wpewebkit()(raises=AttributeError, reason="Logging API is no longer available")
 def test_get_log(driver, pages):
     pages.load("blank.html")
     for log_type in driver.log_types:
