@@ -15,8 +15,12 @@
 # specific language governing permissions and limitations
 # under the License.
 
+import time
+
 import pytest
 
+from selenium.common.exceptions import WebDriverException
+from selenium.webdriver.common.bidi.browsing_context import ReadinessState
 from selenium.webdriver.common.bidi.network import Request
 from selenium.webdriver.common.by import By
 
@@ -68,31 +72,52 @@ def test_clear_request_handlers(driver, pages):
     assert driver.find_element(By.NAME, "login").is_displayed(), "Request not continued"
 
 
-@pytest.mark.xfail_chrome
-@pytest.mark.xfail_edge
 def test_continue_request(driver, pages):
     def callback(request: Request):
         request.continue_request()
 
     callback_id = driver.network.add_request_handler("before_request", callback)
     assert callback_id is not None, "Request handler not added"
-    pages.load("formPage.html")
+    url = pages.url("formPage.html")
+    driver.browsing_context.navigate(context=driver.current_window_handle, url=url, wait=ReadinessState.COMPLETE)
     assert driver.find_element(By.NAME, "login").is_displayed(), "Request not continued"
 
 
-@pytest.mark.xfail_chrome
-@pytest.mark.xfail_edge
 def test_continue_with_auth(driver):
-    callback_id = driver.network.add_auth_handler("user", "passwd")
+    callback_id = driver.network.add_auth_handler("postman", "password")
     assert callback_id is not None, "Request handler not added"
-    driver.get("https://httpbin.org/basic-auth/user/passwd")
+    driver.browsing_context.navigate(
+        context=driver.current_window_handle, url="https://postman-echo.com/basic-auth", wait=ReadinessState.COMPLETE
+    )
     assert "authenticated" in driver.page_source, "Authorization failed"
 
 
-@pytest.mark.xfail_chrome
-@pytest.mark.xfail_edge
 def test_remove_auth_handler(driver):
     callback_id = driver.network.add_auth_handler("user", "passwd")
     assert callback_id is not None, "Request handler not added"
     driver.network.remove_auth_handler(callback_id)
     assert driver.network.intercepts == [], "Intercept not removed"
+
+
+@pytest.mark.xfail_chrome(reason="Data URLs in Network requests are not implemented in Chrome yet")
+@pytest.mark.xfail_edge(reason="Data URLs in Network requests are not implemented in Edge yet")
+@pytest.mark.xfail_firefox(reason="Data URLs in Network requests are not implemented in Firefox yet")
+def test_handler_with_data_url_request(driver, pages):
+    data_requests = []
+    exceptions = []
+
+    def callback(request: Request):
+        if request.url.startswith("data:"):
+            data_requests.append(request)
+        try:
+            request.continue_request()
+        except WebDriverException as e:
+            exceptions.append(e)
+
+    driver.network.add_request_handler("before_request", callback)
+    url = pages.url("data_url.html")
+    driver.browsing_context.navigate(context=driver.current_window_handle, url=url, wait=ReadinessState.COMPLETE)
+    time.sleep(1)  # give callback time to complete
+    assert driver.find_element(By.ID, "data-url-image").is_displayed()
+    assert len(data_requests) > 0, "BiDi event not captured"
+    assert len(exceptions) == 0, "Exception raised when continuing request in callback"
